@@ -38,7 +38,21 @@ Axn(soa08Act, x=30, n=10, i=0.04,power=2)-Axn(soa08Act, x=30, n=10, i=0.04,power
 ###################################################
 ### code chunk number 6: act4
 ###################################################
+#should be 0.1048
+Axn(soa08Act, x=30,k=4)
+
+
+###################################################
+### code chunk number 7: act5
+###################################################
 #should be 0.01155
 Axn(soa08Act, 50,20)/axn(soa08Act, 50,20)
 
 
+###################################################
+### code chunk number 8: act6
+###################################################
+#should be 0.1068
+axn(soa08Act, x=60,k=12)
+
+
